@@ -1,7 +1,6 @@
 __all__ = ('SmsMTSPoint', 'SmsMTS2Point', 'SmsToReferralPoint')
 
 from expressmoney_service.api import *
-from phonenumber_field.modelfields import PhoneNumberField
 
 _SERVICE = 'services'
 
@@ -16,7 +15,7 @@ class _SmsMTS2CreateContract(Contract):
 
 class _SmsToReferralCreateContract(Contract):
     message = serializers.CharField(max_length=130)
-    phone_number = PhoneNumberField()
+    phone_number = serializers.CharField(max_length=20)
 
 
 class _SmsMTSResponseContract(_SmsMTSCreateContract):
@@ -38,7 +37,7 @@ class _SmsMTS2ID(ID):
 class _SmsToReferralID(ID):
     _service = _SERVICE
     _app = 'sms_mts'
-    _view_set = 'sms_to_number'
+    _view_set = 'sms_to_referral'
 
 
 class SmsMTSPoint(ResponseMixin, CreatePointMixin, ContractPoint):
